==> deepin-manual_6.5.25.tar.xz: BUILD/translations/deepin-manual_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" sourcelanguage="en_US" language="bo">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="322"/>
        <source>Learn Basic Operations</source>
        <translation>གཞི་རྩའི་བཀོལ་སྤྱོད་ལ་རྒྱུས་ལོན།</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="324"/>
        <source>Common Application Libraries</source>
        <translation>རྒྱུན་སྤྱོད་ཉེར་སྤྱོད་མཛོད།</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="326"/>
        <source>Desktop Environment</source>
        <translation>ཅོག་ངོས་ཁོར་ཡུག</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
        <source>Search for &quot;%1&quot; in the full text</source>
        <translation>ཡིག་ཆ་ཚང་མའི་ནང་དུ་“%1”འཚོལ་བ།</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="301"/>
        <source>The content was updated</source>
        <translation>མིག་སྔའི་ནང་དོན་གསར་བརྗེ་བྱས་ཟིན།</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="624"/>
        <source>Search</source>
        <translation>འཚོལ་ཞིབ།</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="627"/>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>Support</source>
        <translation>ཞབས་ཞུ་དང་རོགས་སྐྱོར།</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="836"/>
        <source>Copy</source>
        <translation>པར་སློག</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
        <source>Quick Start</source>
        <translation>མགྱོགས་པོ་འཛུལ་བ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
        <source>Video Guide</source>
        <translation>བརྙན་འཕྲིན་ཕྱོགས་སྟོན།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="23"/>
        <source>System</source>
        <translation>མ་ལག</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="24"/>
        <source>Applications</source>
        <translation>ཉེར་སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>No search results</source>
        <translation>འཚོལ་ཞིབ་བྱས་འབྲས་མེད།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
        <source>Home</source>
        <translation>གཙོ་ངོས་སུ་ཕྱིར་ལོག་པ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
        <source>  result</source>
        <translation>འབྲས་བུ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>  results</source>
        <translation>འབྲས་བུ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
        <source>Click to view </source>
        <translation>མནན་ནས་ལྟ་བ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>View all</source>
        <translation>ཆ་ཚང་ལ་ལྟ་བ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
        <source>App Store</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="105"/>
        <source>Manual</source>
        <translation>རོགས་རམ་ལག་དེབ།</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="106"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>རོགས་རམ་ལག་དེབ་ནི་སྤྱོད་མཁན་གྱིས་བཀོལ་སྤྱོད་མ་ལག་དང་དེའི་མ་ལག་ཉེར་སྤྱོད་ལ་རྒྱུས་ལོན་བྱེད་རོགས་བྱེད་པ་དང་། ཞིབ་ཕྲའི་སྤྱོད་ཐབས་དང་ནུས་པའི་གསལ་བཤད་འདོན་སྤྲོད་བྱེད་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="765"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="780"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>

==> deepin-manual_6.5.35.tar.xz: BUILD/translations/deepin-manual_bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo" sourcelanguage="en_US">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="363"/>
        <source>Learn Basic Operations</source>
        <translation>གཞི་རྩའི་བཀོལ་སྤྱོད་ལ་རྒྱུས་ལོན།</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="366"/>
        <source>Common Application Libraries</source>
        <translation>རྒྱུན་སྤྱོད་ཉེར་སྤྱོད་མཛོད།</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="369"/>
        <source>Desktop Environment</source>
        <translation>ཅོག་ངོས་ཁོར་ཡུག</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
        <source>Search for "%1" in the full text</source>
        <translation>ཡིག་ཆ་ཚང་མའི་ནང་དུ་“%1”འཚོལ་བ།</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="363"/>
        <source>The content was updated</source>
        <translation>མིག་སྔའི་ནང་དོན་གསར་བརྗེ་བྱས་ཟིན།</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="767"/>
        <source>Search</source>
        <translation>འཚོལ་ཞིབ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
        <source>Support</source>
        <translation>ཞབས་ཞུ་དང་རོགས་སྐྱོར།</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="1038"/>
        <source>Copy</source>
        <translation>པར་སློག</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>Quick Start</source>
        <translation>མགྱོགས་པོ་འཛུལ་བ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
        <source>Video Guide</source>
        <translation>བརྙན་འཕྲིན་ཕྱོགས་སྟོན།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
        <source>System</source>
        <translation>མ་ལག</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>Applications</source>
        <translation>ཉེར་སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
        <source>No search results</source>
        <translation>འཚོལ་ཞིབ་བྱས་འབྲས་མེད།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>Home</source>
        <translation>གཙོ་ངོས་སུ་ཕྱིར་ལོག་པ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>  result</source>
        <translation>འབྲས་བུ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
        <source>  results</source>
        <translation>འབྲས་བུ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
        <source>Click to view </source>
        <translation>མནན་ནས་ལྟ་བ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
        <source>View all</source>
        <translation>ཆ་ཚང་ལ་ལྟ་བ།</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
        <source>App Store</source>
        <translation>སྤྱི་ཟླ་བོད་སྒྲིག་འབྱུང་</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="136"/>
        <source>Manual</source>
        <translation>རོགས་རམ་ལག་དེབ།</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="137"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>རོགས་རམ་ལག་དེབ་ནི་སྤྱོད་མཁན་གྱིས་བཀོལ་སྤྱོད་མ་ལག་དང་དེའི་མ་ལག་ཉེར་སྤྱོད་ལ་རྒྱུས་ལོན་བྱེད་རོགས་བྱེད་པ་དང་། ཞིབ་ཕྲའི་སྤྱོད་ཐབས་དང་ནུས་པའི་གསལ་བཤད་འདོན་སྤྲོད་བྱེད་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="952"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="969"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>
